<?php
/**
 * FiloBlu srl
 *
 * @category   FiloBlu
 * @package    FiloBlu_ReCaptcha
 * @copyright  FiloBlu srl (http://www.filoblu.com)
 *
 */

namespace FiloBlu\ReCaptcha\Model;

use Magento\Framework\HTTP\PhpEnvironment\RemoteAddress;
use Magento\Framework\Json\DecoderInterface;
use FiloBlu\ReCaptcha\Api\ValidateInterface;
use FiloBlu\ReCaptcha\Helper\Data;
use ReCaptcha\ReCaptcha;
use Magento\Framework\App\RequestInterface;
use Symfony\Component\Config\Definition\Exception\Exception;

class Validate implements ValidateInterface
{
    protected $requestInterface;
    protected $remoteAddress;
    protected $helperData;
    protected $jsonDecoderInterface;

    public function __construct(
        RequestInterface $requestInterface,
        RemoteAddress $remoteAddress,
        Data $helperData,
        DecoderInterface $jsonDecoderInterface
    ) {
        $this->requestInterface = $requestInterface;
        $this->remoteAddress = $remoteAddress;
        $this->helperData = $helperData;
        $this->jsonDecoderInterface = $jsonDecoderInterface;
    }

    /**
     * Return true if reCaptcha validation has passed
     * @return bool
     */
    public function validate()
    {
        $secret = $this->helperData->getPrivateKey();

        $userIp = $this->remoteAddress->getRemoteAddress();

        $reCatchaResponse = $this->requestInterface->getParam('g-recaptcha-response', '');

        // Check if it is a JSON payload
        if (!$reCatchaResponse) {
            $content = $this->requestInterface->getContent();
            if ($content) {
                try {
                    $jsonParams = $this->jsonDecoderInterface->decode($content);
                    if (isset($jsonParams['g-recaptcha-response'])) {
                        $reCatchaResponse = $jsonParams['g-recaptcha-response'];
                    }
                } catch (\Exception $e) {
                    $reCatchaResponse = '';
                }
            }
        }

        if (!$reCatchaResponse) {
            return false;
        }

        return $reCatchaResponse;
    }
}
